@@ -1,7 +1,10 @@
 .onLoad <-
 function(libname, pkgname)
 {
-    require("RWeka")
+    ## Argh.  We do need RWeka's .onLoad() to be run so that the JVM
+    ## gets initialized properly ...
+    loadNamespace("RWeka")
+    
     rJava::.jmergeClassPath(system.file("jar", "snowball.jar",
                                         package = pkgname,
                                         lib.loc = libname))
